SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)

Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af
This commit is contained in:
ROCm CI Service Account
2022-06-30 13:29:27 +05:30
committed by GitHub
parent 84c23e2b41
commit 2667f3e225
11 changed files with 24 additions and 24 deletions
+1 -1
View File
@@ -75,7 +75,7 @@ bool p_atomicNoRet = false;
template <typename T>
__global__ void atomicnoret_manywaves(T* C_d) {
size_t tid = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x);
size_t tid = (blockIdx.x * blockDim.x + threadIdx.x);
switch (tid % 9) {
case 0:
atomicAddNoRet(C_d, INCREMENT_VALUE);